package com.jkcredit.invoice.hub.service.apiCompany;

import cn.com.taiji.sdk.comm.ETCCommHelper;
import cn.com.taiji.sdk.model.comm.protocol.eoms.company.CompanyAddRequest;
import cn.com.taiji.sdk.model.comm.protocol.eoms.company.CompanyAddResponse;
import cn.com.taiji.sdk.model.comm.protocol.eoms.company.CompanyQueryRequest;
import cn.com.taiji.sdk.model.comm.protocol.eoms.company.CompanyQueryResponse;
import com.alibaba.fastjson.JSONObject;
import com.jkcredit.invoice.hub.constant.CommonConstant;
import com.jkcredit.invoice.hub.service.base.BaseService;
import com.jkcredit.invoice.hub.spi.lang.exception.ServiceException;
import com.jkcredit.invoice.hub.spi.rest.data.ApiResponseData;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.io.IOException;

/**
 * @description:
 * @author: xusonglin
 * @create: 2020/1/15 23:50
 * @version: V1.0
 **/
@Slf4j
@Service
public class ApiCompanyServiceImpl extends BaseService implements ApiCompanyService {

    @Override
    public ApiResponseData companyQuery(JSONObject param) {
        long costTimeStart = System.currentTimeMillis();
        String result;

        CompanyQueryRequest request = new CompanyQueryRequest();
        request.setCompanyName(param.get("companyName").toString().trim());
        request.setTaxpaterCode(param.get("taxplayerCode").toString().trim());
        String fileName = request.getFilename();

        try {
            // 调用upload 发送数据
            CompanyQueryResponse response = ETCCommHelper.upload(fileName, request, CompanyQueryResponse.class);

            result = response.toJson();
            long costTimeEnd = System.currentTimeMillis();
            log.info("[-companyQuery-] result is " + result.replaceAll("\r|\n", "") + " , request is "
                    + param + ",costtime=" + (costTimeEnd - costTimeStart) + ",startTime=" + costTimeStart
                    + ",endTime=" + costTimeEnd);
        } catch (IOException e) {
            log.error("[-companyQuery-] 网络异常 " + e);
            throw new ServiceException(CommonConstant.QUERY_FAILED);
        } catch (Exception apie) {
            log.error("[-companyQuery-] 错误信息：" + apie.getMessage());
            throw new ServiceException(CommonConstant.QUERY_FAILED);
        }
        return analyzeApiResult(result);
    }

    @Override
    public ApiResponseData queryAdd(JSONObject param) {
        long costTimeStart = System.currentTimeMillis();
        String result;

        CompanyAddRequest request = new CompanyAddRequest();
        request.setName(param.getString("name").trim());
        request.setCompanyType(param.getInteger("companyType"));
        request.setTaxpayerCode(param.getString("taxplayerCode").trim());
        request.setOperatingRangeType(param.getInteger("operatingRangeType"));
        request.setContact(param.getString("contact").trim());
        request.setTel(param.getString("tel").trim());
        request.setEmergencyContact(param.getString("emergencyContact").trim());
        request.setEmergencyTel(param.getString("emergencyTel").trim());
        request.setBuyerName(param.getString("buyerName").trim());
        request.setBuyerTaxpayerCode(param.getString("buyerTaxpayerCode").trim());
        request.setBuyerAddr(param.getString("buyerAddr").trim());
        request.setBuyerTel(param.getString("buyerTel").trim());
        request.setBuyerBank(param.getString("buyerBank").trim());
        request.setBuyerBankAccount(param.getString("buyerBankAccount").trim());
        String fileName = request.getFilename();

        try {
            // 调用upload 发送数据
            CompanyAddResponse response = ETCCommHelper.upload(fileName, request, CompanyAddResponse.class);

            result = response.toJson();
            long costTimeEnd = System.currentTimeMillis();
            log.info("[-queryAdd-] result is " + result.replaceAll("\r|\n", "") + " , request is "
                    + param + ",costtime=" + (costTimeEnd - costTimeStart) + ",startTime=" + costTimeStart
                    + ",endTime=" + costTimeEnd);
        } catch (IOException e) {
            log.error("[-queryAdd-] 网络异常 " + e);
            throw new ServiceException(CommonConstant.QUERY_FAILED);
        } catch (Exception apie) {
            log.error("[-queryAdd-] 错误信息：" + apie.getMessage());
            throw new ServiceException(CommonConstant.QUERY_FAILED);
        }
        return analyzeApiResult(result);
    }
}
